@@ -1,8 +1,8 @@
 from dpsutil.attrdict.attrdict import AttrDict
-from dpsutil.attrdict.defaultdict import DefaultTypeDict, TypedDict, DefaultDict
+from dpsutil.attrdict.defaultdict import DefaultTypeDict, TypedDict, DefaultDict, ReadOnlyDict
 from dpsutil.attrdict.decorator import attribute_dict, default_type_dict, default_dict
 
 __all__ = [
-    'AttrDict', 'DefaultTypeDict', 'TypedDict', 'DefaultDict',
+    'AttrDict', 'DefaultTypeDict', 'TypedDict', 'DefaultDict', 'ReadOnlyDict',
     'attribute_dict', 'default_type_dict', 'default_dict'
 ]
