@@ -110,7 +110,6 @@ class BufferReader(object):
         self.thread = None
 
     def __iter__(self):
-        self.stream = ffmpeg.run_async(self.source_stream, pipe_stdout=True)
         self.thread = Thread(target=self.read_buffer).start()
         return self
 
@@ -118,6 +117,7 @@ class BufferReader(object):
         return self.pool_frames.get()
 
     def read_buffer(self):
+        self.stream = ffmpeg.run_async(self.source_stream, pipe_stdout=True)
         while self.stream.poll() is None:
             buffer = self.stream.stdout.read(self.chunk_size)
             self.pool_frames.put(buffer)
@@ -187,7 +187,6 @@ class VideoIterator(object):
         with self.pool_frames.mutex:
             self.pool_frames.queue.clear()
 
-        self.stream = ffmpeg.run_async(self.source_stream, pipe_stdout=True)
         self.thread = Thread(target=self.__read_buffer)
         self.thread.start()
 
@@ -210,6 +209,7 @@ class VideoIterator(object):
         return Frame(buffer, self.size)
 
     def __read_buffer(self):
+        self.stream = ffmpeg.run_async(self.source_stream, pipe_stdout=True)
         while self.stream.poll() is None:
             buffer = self.stream.stdout.read(self.read_byte_size)
 
@@ -229,6 +229,8 @@ class VideoIterator(object):
             self.pool_frames.get_nowait()
         except IndexError:
             pass
+        except Empty:
+            pass
 
         self.pool_frames.put(self.__STOP_BYTES)
         self.stream.kill()
@@ -252,7 +254,9 @@ class VideoInfo(object):
         # check source
         super().__init__()
 
-        opts = {}
+        opts = {
+            "probesize": 32
+        }
 
         # stream
         if src.startswith("rtsp"):
@@ -268,10 +272,19 @@ class VideoInfo(object):
 
         # meta-data
         self.src = src
-        self.fps = round(eval(self.info['r_frame_rate']))
+        try:
+            self.fps = round(eval(self.info['avg_frame_rate']))
+        except ZeroDivisionError:
+            self.fps = round(eval(self.info['r_frame_rate']))
+
         self.height = self.info['height']
         self.width = self.info['width']
 
+        try:
+            self.rotation = self.info['tags']['rotate']
+        except KeyError:
+            self.rotation = None
+
 
 class VideoCapture(object):
     """
@@ -371,8 +384,8 @@ class VideoCapture(object):
     def fps(self):
         return self.__meta.fps
 
-    def read2pipe(self, encoder=H264_ENCODER, chunk_size=128, output_size=None, keep_ratio=True, duration=0, fps=0, pix_fmt=RGB24, auto_stop=None,
-                  log_level=LOG_ERROR):
+    def read2pipe(self, encoder=H264_ENCODER, chunk_size=128, output_size=None, keep_ratio=True, duration=0, fps=0,
+                  pix_fmt=RGB24, log_level=LOG_ERROR):
         """
         Generate VideoIterator which yield once frame by frame.
 
@@ -397,9 +410,6 @@ class VideoCapture(object):
         pix_fmt: str
             (Default: RGB24) Format of each pixel in frame.
 
-        auto_stop: int
-            (Default: infinite) If process wasn't read frame in seconds, reader would automatic stopped.
-
         log_level: LogLevel
             Log level of ffmpeg
 
@@ -424,14 +434,22 @@ class VideoCapture(object):
                 output_size[1]
             )
 
+        if self.__meta.rotation in ['90', '270']:
+            output_size = output_size[::-1]
+
         output_options = {
             "c:v": encoder,
+            "preset": "veryfast",
+            "vprofile": "baseline",
             "format": 'h264' if encoder == H264_ENCODER else "h265",
             "pix_fmt": pix_fmt,
             "loglevel": log_level,
-            "s": f'{output_size[0]}x{output_size[1]}'
+            'probesize': 32
         }
 
+        if output_size != self.size:
+            output_options["s"] = f'{output_size[0]}x{output_size[1]}'
+
         # handle FPS
         if fps > 0:
             # manual set
@@ -454,7 +472,7 @@ class VideoCapture(object):
 
         return BufferReader(capture, chunk_size)
 
-    def read(self, output_size=None, keep_ratio=True, duration=0, fps=None, pix_fmt=RGB24, auto_stop=None,
+    def read(self, output_size=None, keep_ratio=True, duration=0, fps=0, pix_fmt=RGB24, auto_stop=None,
              log_level=LOG_ERROR):
         """
         Generate VideoIterator which yield once frame by frame.
@@ -503,15 +521,29 @@ class VideoCapture(object):
                 output_size[1]
             )
 
+        if self.__meta.rotation in ['90', '270']:
+            output_size = output_size[::-1]
+
         output_options = {
             "format": 'rawvideo',
             "pix_fmt": pix_fmt,
             "loglevel": log_level,
-            "s": f'{output_size[0]}x{output_size[1]}'
+            'probesize': 32
         }
 
-        if fps:
-            output_options['r'] = fps
+        if output_size != self.size:
+            output_options["s"] = f'{output_size[0]}x{output_size[1]}'
+
+        # handle FPS
+        if fps > 0:
+            # manual set
+            output_options["r"] = fps
+        elif self.is_stream:
+            # sync with time
+            output_options["vsync"] = "vfr"
+        else:
+            # same source file
+            output_options["r"] = self.fps
 
         if duration:
             output_options['t'] = duration
